@@ -1,6 +1,7 @@
 test_that("Test bbox", {
   img <- system.file("img/UK_flag.png", package = "rasterpic")
-  x <- sf::st_read(system.file("gpkg/UK.gpkg", package = "rasterpic"),
+  x <- sf::st_read(
+    system.file("gpkg/UK.gpkg", package = "rasterpic"),
     quiet = TRUE
   )
 
@@ -11,7 +12,7 @@ test_that("Test bbox", {
 
   expect_true(terra::crs(raster) == "")
 
-  png_dim <- png::readPNG(img)
+  png_dim <- terra::rast(img, noflip = TRUE)
   expect_equal(asp_ratio(raster), dim(png_dim)[2] / dim(png_dim)[1])
 
   # Same y coords
@@ -25,7 +26,8 @@ test_that("Test bbox", {
 
 test_that("Test bbox with projs", {
   img <- system.file("img/UK_flag.png", package = "rasterpic")
-  x <- sf::st_read(system.file("gpkg/UK.gpkg", package = "rasterpic"),
+  x <- sf::st_read(
+    system.file("gpkg/UK.gpkg", package = "rasterpic"),
     quiet = TRUE
   )
 
@@ -38,8 +40,7 @@ test_that("Test bbox with projs", {
   raster <- rasterpic_img(x, img, crs = crs_wkt_sf)
   expect_false(terra::crs(raster) == "")
 
-
-  png_dim <- png::readPNG(img)
+  png_dim <- terra::rast(img, noflip = TRUE)
   expect_equal(asp_ratio(raster), dim(png_dim)[2] / dim(png_dim)[1])
 
   # Same y coords
@@ -53,7 +54,6 @@ test_that("Test bbox with projs", {
   # On mask message
   expect_snapshot(mask <- rasterpic_img(x, img, crs = crs_wkt_sf, mask = TRUE))
 
-
   expect_true(terra::ext(raster) == terra::ext(mask))
 
   # On crop ok
