@@ -4,11 +4,12 @@ test_that("Test error online", {
   skip_if_offline()
 
   img <- "http://this_is_an_error_url.fake"
-  x <- sf::st_read(system.file("gpkg/UK.gpkg", package = "rasterpic"),
+  x <- sf::st_read(
+    system.file("gpkg/UK.gpkg", package = "rasterpic"),
     quiet = TRUE
   )
 
-  expect_error(rasterpic_img(x, img))
+  expect_snapshot(rasterpic_img(x, img), error = TRUE)
 })
 
 test_that("Test image online", {
@@ -17,7 +18,8 @@ test_that("Test image online", {
   skip_if_offline()
 
   img <- "https://i.imgur.com/6yHmlwT.jpeg"
-  x <- sf::st_read(system.file("gpkg/UK.gpkg", package = "rasterpic"),
+  x <- sf::st_read(
+    system.file("gpkg/UK.gpkg", package = "rasterpic"),
     quiet = TRUE
   )
 
