@@ -1,6 +1,7 @@
 test_that("Test SpatExtent", {
   img <- system.file("img/UK_flag.png", package = "rasterpic")
-  x <- sf::st_read(system.file("gpkg/UK.gpkg", package = "rasterpic"),
+  x <- sf::st_read(
+    system.file("gpkg/UK.gpkg", package = "rasterpic"),
     quiet = TRUE
   )
 
@@ -11,7 +12,7 @@ test_that("Test SpatExtent", {
 
   expect_true(terra::crs(raster) == "")
 
-  png_dim <- png::readPNG(img)
+  png_dim <- terra::rast(img, noflip = TRUE)
   expect_equal(asp_ratio(raster), dim(png_dim)[2] / dim(png_dim)[1])
 
   # Same y coords
@@ -25,7 +26,8 @@ test_that("Test SpatExtent", {
 
 test_that("Test SpatExtent with projs", {
   img <- system.file("img/UK_flag.png", package = "rasterpic")
-  x <- sf::st_read(system.file("gpkg/UK.gpkg", package = "rasterpic"),
+  x <- sf::st_read(
+    system.file("gpkg/UK.gpkg", package = "rasterpic"),
     quiet = TRUE
   )
 
@@ -40,7 +42,7 @@ test_that("Test SpatExtent with projs", {
   raster <- rasterpic_img(x, img, crs = crs_wkt_terra)
   expect_true(terra::crs(raster) == crs_wkt_terra)
 
-  png_dim <- png::readPNG(img)
+  png_dim <- terra::rast(img, noflip = TRUE)
   expect_equal(asp_ratio(raster), dim(png_dim)[2] / dim(png_dim)[1])
 
   # Same y coords
